<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since  1.0.0
 * @param  array $args Configuration arguments.
 * @return array
 */
function roku_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'roku_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function roku_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Blog list layouts
	$blog_list = roku_mod( PREFIX . 'blog-list-layouts' );
	if ( is_home() && ! empty( $blog_list ) ) {
		$classes[] = 'blog-layout-' . $blog_list;
	}

	// Container layouts
	$container = roku_mod( PREFIX . 'container-layouts' );
	$classes[] = 'container-' . $container;

	if ( is_page_template( 'page-templates/block.php' ) ) {
		$classes[] = 'layout-page-builder';
	}

	return $classes;
}
add_filter( 'body_class', 'roku_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function roku_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	return $classes;
}
add_filter( 'post_class', 'roku_post_classes' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function roku_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'roku_excerpt_more' );

/**
 * Change excerpt length
 *
 * @since 1.0.0
 */
function roku_excerpt_length( $length ) {

	// Default length
	$length = 55;

	// Get the blog list layout
	// Custom excerpt length
	$blog_list = roku_mod( PREFIX . 'blog-list-layouts' );
	if ( is_home() ) {
		if ( $blog_list == 'grid' ) {
			$length = 20;
		}
	}

	return $length;
}
add_filter( 'excerpt_length', 'roku_excerpt_length', 999 );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 *
 * @since 1.0.0
 */
function roku_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );

	// bbPress
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'roku_remove_theme_layout_metabox', 11 );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function roku_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'roku_page_sidebar_plugin' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function roku_contact_info_fields( $contactmethods ) {
	$contactmethods['tw_username'] = esc_html__( 'Twitter Username', 'roku' );
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'roku' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'roku' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'roku' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'roku' );
	$contactmethods['linkedin']   = esc_html__( 'Linkedin URL', 'roku' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'roku_contact_info_fields' );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function roku_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	} elseif ( is_attachment() ) {
		$title = esc_html__( 'Attachment', 'roku' );
	} elseif ( is_search() ) {
		$title = sprintf( esc_html__( 'Search Results for: %s', 'roku' ), '<span>' . get_search_query() . '</span>' );
	} elseif ( is_404() ) {
		$title = esc_html__( 'Oops! That page can&rsquo;t be found.', 'roku' );
	} elseif ( is_page() ) {
		$title = get_the_title();
	} else {
		$title = esc_html__( 'Blog', 'roku' );
	}

	return $title;
}
add_filter( 'get_the_archive_title', 'roku_extend_archive_title' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function roku_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'roku_customize_tag_cloud' );
add_filter( 'woocommerce_product_tag_cloud_widget_args', 'roku_customize_tag_cloud' );

/**
 * Modifies the theme layout on different pages.
 *
 * @since  1.0.0
 */
function roku_mod_theme_layout( $layout ) {

	// Attachment layout
	if ( is_attachment() && wp_attachment_is_image() || is_page_template( 'page-templates/block.php' ) || is_page_template( 'page-templates/teams.php' ) ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	// Blog layout
	$blog_layouts = roku_mod( PREFIX . 'blog-layouts' );
	if ( is_home() && ! empty( $blog_layouts ) ) {
		$layout = $blog_layouts;
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'roku_mod_theme_layout', 15 );

/**
 * Custom <header> attributes
 */
function roku_attr_header( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_header',  'roku_attr_header' );

/**
 * Custom <nav> attributes
 */
function roku_attr_menu( $attr ) {
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_menu', 'roku_attr_menu' );

/**
 * Custom <main> attributes
 */
function roku_attr_main( $attr ) {
	$attr['class'] = 'site-main';
	unset( $attr['id'] );
	unset( $attr['role'] );

	if ( isset( $attr['itemprop'] ) ) {
		$attr['itemtype']  = 'http://schema.org/WebPageElement';
		$attr['itemscope'] = 'itemscope';
	}

	return $attr;
}
add_filter( 'hybrid_attr_content', 'roku_attr_main' );

/**
 * Custom sidebar attributes
 */
function roku_attr_sidebar( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_sidebar', 'roku_attr_sidebar' );

/**
 * Custom <footer> attributes
 */
function roku_attr_footer( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_footer', 'roku_attr_footer' );

/**
 * Custom post <article> attributes
 */
function roku_attr_post( $attr ) {

	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_post', 'roku_attr_post' );

/**
 * Custom entry-terms
 */
function roku_attr_entry_terms( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-terms', 'roku_attr_entry_terms' );

/**
 * Custom entry-title
 */
function roku_attr_entry_title( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-title', 'roku_attr_entry_title' );

/**
 * Custom entry-published
 */
function roku_attr_entry_published( $attr ) {
	unset( $attr['class'] );
	unset( $attr['content'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-published', 'roku_attr_entry_published' );

/**
 * Custom entry-author
 */
function roku_attr_entry_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-author', 'roku_attr_entry_author' );

/**
 * Custom entry-summary
 */
function roku_attr_entry_summary( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-summary', 'roku_attr_entry_summary' );

/**
 * Custom entry-content
 */
function roku_attr_entry_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-content', 'roku_attr_entry_content' );
