<?php
/**
 * WooCommerce compatibility and custom functions
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

// Declare WooCommerce support
add_theme_support( 'woocommerce' );

/**
 * Define WooCommerce image sizes.
 *
 * @since  1.0.0
 */
function roku_woocommerce_image_dimensions() {
	global $pagenow;

	if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
		return;
	}

	$catalog = array(
		'width' 	=> '420',
		'height'	=> '540',
		'crop'		=> 1
	);
	$single = array(
		'width' 	=> '680',
		'height'	=> '680',
		'crop'		=> 1
	);
	$thumbnail = array(
		'width' 	=> '180',
		'height'	=> '180',
		'crop'		=> 1
	);

	// Image sizes
	update_option( 'shop_catalog_image_size',   $catalog );     // Product category thumbs
	update_option( 'shop_single_image_size',    $single );       // Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); // Image gallery thumbs

}
add_action( 'after_switch_theme', 'roku_woocommerce_image_dimensions', 1 );

/**
 * Cart Fragments
 * Ensure cart contents update when products are added to the cart via AJAX
 *
 * @since  1.0.0
 */
function roku_cart_link_fragment( $fragments ) {
	global $woocommerce;

	ob_start();

	roku_cart_link();

	$fragments['a.cart-contents'] = ob_get_clean();

	return $fragments;
}
if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '2.3', '>=' ) ) {
	add_filter( 'woocommerce_add_to_cart_fragments', 'roku_cart_link_fragment' );
} else {
	add_filter( 'add_to_cart_fragments', 'roku_cart_link_fragment' );
}

/**
 * Related Products Args
 *
 * @since 1.0.0
 */
function roku_related_products( $args ) {
	$args = apply_filters( 'roku_related_products_args', array(
		'posts_per_page' => 4,
		'columns'        => 4,
	) );

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'roku_related_products' );

/**
 * Upsells Products Args
 *
 * @since 1.0.0
 */
function roku_upsells_products( $args ) {
	$args = apply_filters( 'roku_upsells_products_args', array(
		'posts_per_page' => 4,
		'columns'        => 4,
		'orderby'        => 'rand'
	) );

	return $args;
}
add_filter( 'woocommerce_upsell_display_args', 'roku_upsells_products' );

/**
 * Product gallery thumnail columns.
 *
 * @since  1.0.0
 */
function roku_thumbnail_columns() {
	return intval( apply_filters( 'roku_product_thumbnail_columns', 4 ) );
}
add_filter( 'woocommerce_product_thumbnails_columns', 'roku_thumbnail_columns' );

/**
 * Products per page
 *
 * @since  1.0.0
 */
function roku_products_per_page() {
	return intval( apply_filters( 'roku_products_per_page', 12 ) );
}
add_filter( 'loop_shop_per_page', 'roku_products_per_page' );

/**
 * Default loop columns on product archives
 *
 * @since  1.0.0
 */
function roku_loop_columns() {
	return apply_filters( 'roku_loop_columns', 4 ); // 4 products per row
}
add_filter( 'loop_shop_columns', 'roku_loop_columns' );

/**
 * Limit cross sells to 2
 *
 * @since  1.0.0
 */
function roku_cross_sells_limit() {
	return 2;
}
add_filter( 'woocommerce_cross_sells_total', 'roku_cross_sells_limit' );

/**
 * Remove WooCommerce Grid/List view extensions
 *
 * @since  1.0.0
 */
function roku_remove_gridlist_styles() {
	wp_dequeue_style( 'grid-list-button' );
}
add_action( 'wp_enqueue_scripts', 'roku_remove_gridlist_styles', 30 );

/**
 * WooCommerce pages layout
 *
 * @since  1.0.0
 */
function roku_woo_layouts( $layout ) {

	// WooCommerce pages layouts.
	if ( is_woocommerce() || is_cart() || is_checkout() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	// Shop layouts
	$shop = roku_mod( PREFIX . 'shop-layouts' );
	if ( is_shop() ) {
		$layout = $shop;
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'roku_woo_layouts', 15 );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function roku_woo_page_title( $title ) {

	if ( is_post_type_archive( 'product' ) ) {
		$title = esc_html__( 'Shop', 'roku' );
	} elseif ( is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) {
		$tax = get_queried_object();
		$title = $tax->name;
	} elseif ( is_singular( 'product' ) ) {
		$title = get_the_title();
	} elseif ( is_cart() || is_checkout() ) {
		$title = get_the_title();
	}

	return $title;
}
add_filter( 'get_the_archive_title', 'roku_woo_page_title' );

/**
 * Add custom query vars for search property filter
 * value sent from searchform-custom.php
 *
 * @since 1.0
 */
function roku_add_query_vars_filter( $vars ){
	$vars[] = "stock";
	return $vars;
}
add_filter( 'query_vars', 'roku_add_query_vars_filter' );

/**
 * Search filter for Property
 * value sent from searchform-custom.php
 *
 * @since 1.0
 */
function roku_custom_filters( $query ) {

	if ( ! is_admin() && $query->is_main_query() ) {

		if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
			return;
		}

		// https://tarei.me/2014/02/03/build-custom-wp-query-loop-getting-woocommerce-stock-products/
		$stock = get_query_var( 'stock' );
		if ( ! empty( $stock ) || ( 0 != $stock ) ) {
			switch ( $stock ) {
				case 'in':
					$value = 'instock';
					break;

				case 'out':
					$value = 'outofstock';
					break;

				default:
					$value = '';
					break;
			}
			$meta_query[] = array(
				'key'     => '_stock_status',
				'value'   => $value, // 'outofstock',
				'compare' => '=='
			);
		}

		// run the meta_query
		if ( isset( $meta_query ) && $meta_query ) {
			$query->set( 'meta_query', $meta_query );
		}

	}

	return $query;
}
add_filter( 'pre_get_posts', 'roku_custom_filters' );
